==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/misc/misc.m <==
extern const char **_dictionary_misc;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_misc;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_misc("misc",_dictionary_misc,75,5);\
	void dummy_dict_misc(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_misc[id]
	#define MSG_B(id,m,n)	_dictionary_misc[id]
	#define MSG_R(id)	_dictionary_misc[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_misc,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_misc,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_misc,id)
#endif
#define E_SETOWNER	0
#define E_SETGROUP	1
#define F_CORRPATH	2
#define T_MODCONFPATH	3
#define I_MODCONFPATH	4
#define T_LISTCONF	5
#define I_LISTCONF	6
#define P_MODCONF	7
#define P_COPYSYSFILES	8
#define E_CANTDO	9
#define E_WRITE	10
#define E_READ	11
#define E_UPDATE	12
#define E_OUTOFMEM	13
#define T_QUIT	14
#define I_QUIT	15
#define T_ERROR	16
#define I_ICONERROR	17
#define T_PLEASE	18
#define I_ICONNOTICE	19
#define T_AREYOUSURE	20
#define I_DELRECORD	21
#define I_EMPTYSLOT	22
#define T_MODLIST	23
#define I_MODLIST	24
#define E_MODNOPATH	25
#define E_LOADMOD	26
#define E_COMPATMOD	27
#define H_CONFIGP	28
#define L_ARCHIVING	29
#define M_SUBBASE	30
#define M_NETCLIENT	31
#define L_UNARCHIVING	32
#define I_ERASING	33
#define F_CONFVERMODE	34
#define I_AUTO	35
#define T_CONFIGS	36
#define I_ADDVER	37
#define I_CONFVER	38
#define T_CONFVER	39
#define T_NEWCONF	40
#define E_CONFEXIST	41
#define T_ONECONF	42
#define I_ONECONF	43
#define T_OFFICE	44
#define T_HOME	45
#define T_HOMEOFFICE	46
#define M_HARDWARE	47
#define F_TITLE	48
#define T_PICKVER	49
#define I_PICKVER	50
#define I_ARCHCONF	51
#define I_EXTRCONF	52
#define I_KEEPINGOLD	53
#define E_CFGVIRTUAL	54
#define M_STATIONID	55
#define M_NETACCESS	56
#define M_PROFILEDEF	57
#define E_ARCHFAILED	58
#define F_DEFFAM	59
#define T_HOMECONFIG	60
#define T_OFFICECONFIG	61
#define T_SUBSYS	62
#define E_EXTRFORM	63
#define E_EXTRFORMLOG	64
#define I_CURVERIS	65
#define M_USERACCOUNTS	66
#define M_USERPRIV	67
#define T_COMMON	68
#define I_LASTVERIS	69
#define E_APIVERSION	70
#define E_IVLDMULTIAPI	71
#define N_BCASTAPI	72
#define E_NOCONF	73
#define I_ALREADYSEL	74

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/misc/misc.m <==
extern const char **_dictionary_misc;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_misc;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_misc("misc",_dictionary_misc,86,5);\
	void dummy_dict_misc(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_misc[id]
	#define MSG_B(id,m,n)	_dictionary_misc[id]
	#define MSG_R(id)	_dictionary_misc[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_misc,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_misc,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_misc,id)
#endif
#define E_SETOWNER	0
#define E_SETGROUP	1
#define F_CORRPATH	2
#define T_MODCONFPATH	3
#define I_MODCONFPATH	4
#define T_LISTCONF	5
#define I_LISTCONF	6
#define P_MODCONF	7
#define P_COPYSYSFILES	8
#define E_CANTDO	9
#define E_WRITE	10
#define E_READ	11
#define E_UPDATE	12
#define E_OUTOFMEM	13
#define T_QUIT	14
#define I_QUIT	15
#define T_ERROR	16
#define I_ICONERROR	17
#define T_PLEASE	18
#define I_ICONNOTICE	19
#define T_AREYOUSURE	20
#define I_DELRECORD	21
#define I_EMPTYSLOT	22
#define T_MODLIST	23
#define I_MODLIST	24
#define E_MODNOPATH	25
#define E_LOADMOD	26
#define E_COMPATMOD	27
#define H_CONFIGP	28
#define L_ARCHIVING	29
#define M_SUBBASE	30
#define M_NETCLIENT	31
#define L_UNARCHIVING	32
#define I_ERASING	33
#define F_CONFVERMODE	34
#define I_AUTO	35
#define T_CONFIGS	36
#define I_ADDVER	37
#define I_CONFVER	38
#define T_CONFVER	39
#define T_NEWCONF	40
#define E_CONFEXIST	41
#define T_ONECONF	42
#define I_ONECONF	43
#define T_OFFICE	44
#define T_HOME	45
#define T_HOMEOFFICE	46
#define M_HARDWARE	47
#define F_TITLE	48
#define T_PICKVER	49
#define I_PICKVER	50
#define I_ARCHCONF	51
#define I_EXTRCONF	52
#define I_KEEPINGOLD	53
#define E_CFGVIRTUAL	54
#define M_STATIONID	55
#define M_NETACCESS	56
#define M_PROFILEDEF	57
#define E_ARCHFAILED	58
#define F_DEFFAM	59
#define T_HOMECONFIG	60
#define T_OFFICECONFIG	61
#define T_SUBSYS	62
#define E_EXTRFORM	63
#define E_EXTRFORMLOG	64
#define I_CURVERIS	65
#define M_USERACCOUNTS	66
#define M_USERPRIV	67
#define T_COMMON	68
#define I_LASTVERIS	69
#define E_APIVERSION	70
#define E_IVLDMULTIAPI	71
#define N_BCASTAPI	72
#define E_NOCONF	73
#define I_ALREADYSEL	74
#define E_NOSPACE	75
#define H_SELPROF	76
#define T_SUBSYSNAME	77
#define I_SUBSYSNAME	78
#define E_HOWEXTRACTSUB	79
#define E_HOWEXTRACTFILE	80
#define N_ISLOCKED	81
#define N_YOURLOCK	82
#define E_NOSTATUS	83
#define E_SHORTEXEC	84
#define E_CANTEXEC	85
